catalog_to_dd
-------------

.. currentmodule:: eqcorrscan.utils.catalog_to_dd
.. automodule:: eqcorrscan.utils.catalog_to_dd

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       compute_differential_times
       read_phase
       write_catalog
       write_correlations
       write_event
       write_phase
       write_station

    .. comment to end block
